if not Watcher then return end

if select(2, UnitClass('player')) ~= "WARLOCK" then return end

local LBF = LibStub("LibButtonFacade", true)
local L = LibStub("AceLocale-3.0"):GetLocale("Watcher")
local media = LibStub:GetLibrary("LibSharedMedia-3.0");
local C = Watcher.constants

function Watcher:addicon(spellname, spellID)
	C[spellname], _, C[spellname.." Icon"] = GetSpellInfo(spellID)
end
-- generic spells
Watcher:addicon("Corruption", 172)
Watcher:addicon("Curse of Agony", 980)
Watcher:addicon("Death Coil", 6789)
Watcher:addicon("Immolate", 348)
Watcher:addicon("Incinerate", 29722)
Watcher:addicon("Seed of Corruption", 27243)
Watcher:addicon("Shadow Bolt", 686)

-- talented spells and procs
Watcher:addicon("Aftermath", 18119)
Watcher:addicon("Backdraft", 47258)
Watcher:addicon("Shadow Embrace", 32385)
Watcher:addicon("Shadow Mastery", 17800) -- proc from ISB, not the affliction talent
Watcher:addicon("Shadowflame", 47897)
Watcher:addicon("Chaos Bolt", 50796)
Watcher:addicon("Conflagrate", 17962)
Watcher:addicon("Haunt", 48181)
Watcher:addicon("Metamorphosis", 59672)
Watcher:addicon("Soul Fire", 6353)
Watcher:addicon("Soul Link", 19028)
Watcher:addicon("Unstable Affliction", 30108)

-- glyphs
Watcher:addicon("Life Tap", 1454)
Watcher:addicon("Dark Pact", 18220)

-- armors
Watcher:addicon("Demon Armor", 706)
Watcher:addicon("Fel Armor", 28176)

function Watcher:addClassSpells()
Watcher:Apply("Shadow Mastery", "Shadow Bolt", 3, 0, false) -- ISB proc
Watcher:Apply("Shadow Embrace", "Shadow Bolt", 3, 0, true) -- afflic talent
Watcher:Debuff("Corruption")
Watcher:Debuff("Seed of Corruption")
Watcher:Debuff("Curse of Agony")
Watcher:Debuff("Immolate", 1.5)
Watcher:Debuff("Unstable Affliction", 1.5)
Watcher:Capitalize("Immolate", "Conflagrate")
Watcher:Capitalize("Immolate", "Incinerate")
Watcher:Direct("Haunt")
Watcher:Direct("Shadow Bolt")
Watcher:Direct("Shadowflame")
Watcher:Proc("Molten Core", "Incinerate")
Watcher:Proc("Molten Core", "Soul Fire")
Watcher:Proc("Shadow Trance", "Shadow Bolt")
Watcher:Proc("Backlash", "Shadow Bolt")
Watcher:Buff("Life Tap", "Life Tap")
Watcher:BuffPerm("Soul Link")
end

function Watcher:Debuff(name, casttime) -- basically, dots
	local def = Watcher.defaults.char.spell
	k = C[name]
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] = C[name.." Icon"]
	def.trackspell[k] = C[name]
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.stockspell[k] = true
	def.dotthreshold[k] = casttime or 0
	def.caster[k] = true -- ignore other player's debuffs
end

function Watcher:Buff(buff, name) -- buff that can be maintained 100% up
	local def = Watcher.defaults.char.spell
	k = C[name]
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] = C[buff.." Icon"]
	def.trackspell[k] = C[buff]
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.isbuff[k] =  true -- true if %trackspell is an aura on the caster
	def.stockspell[k] = true
end

function Watcher:BuffPerm(name) -- buff that doesn't fade
	local def = Watcher.defaults.char.spell
	k = C[name]
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] = C[name.." Icon"]
	def.trackspell[k] = C[name]
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.isbuff[k] =  true -- true if %trackspell is an aura on the caster
	def.nocd[k] = true -- true if the buff will not fade
	def.stockspell[k] = true
end

function Watcher:Direct(name) -- direct damage and the sort
	local def = Watcher.defaults.char.spell
	k = C[name]
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] =  C[name.." Icon"]
	def.stockspell[k] = true -- no idea
end

function Watcher:Capitalize(debuff, name) -- while %debuff is applied, cast %name
	local def = Watcher.defaults.char.spell
	k = C[name].." w/ "..debuff
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] = C[name.." Icon"]
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.trackspell[k] = C[debuff]
	def.stockspell[k] = true
	def.caster[k] = true -- ignore other player's debuffs
end

function Watcher:Proc(buff, name) -- when %buff is triggered on self, cast %name
	local def = Watcher.defaults.char.spell
	k = C[name].." w/ "..buff
	def.spellname[k] = C[name]
	def.name[k] = k -- sets definition names
	def.icon[k] =  C[buff.." Icon"]
	def.trackspell[k] = buff -- which spell to look for
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.isproc[k] =  true -- true if %trackspell is something that should be shown only when it's there
	def.isbuff[k] =  true -- true if %trackspell is an aura on the caster
	def.stockspell[k] = true
end

function Watcher:Apply(debuff, name, casttime, stack, playercast) -- when %debuff is desired, cast %name
	local def = Watcher.defaults.char.spell
	k = debuff
	def.spellname[k] = C[name]
	def.name[k] = k
	def.icon[k] =  C[debuff.." Icon"]
	def.typedot[k] =  true -- true if looking for an aura (on caster or target)
	def.trackspell[k] = debuff -- which spell to look for
	def.isproc[k] =  true -- true if %trackspell is something that should be shown only when it's there
	def.stockspell[k] = true -- no idea
	def.dotthreshold[k] = casttime or 0
	def.countreq[k] = stack or 0
	def.caster[k] = playercast or true -- false, if you want to count other players' debuffs; true to require player's casts
end